@@ -2,12 +2,18 @@ import inspect
 import types 
 
 
-__all__ = ["expose", "make_callable", "AWSpiderPlugin"]
+__all__ = ["aliases", "expose", "make_callable", "AWSpiderPlugin"]
 EXPOSED_FUNCTIONS = {}
 CALLABLE_FUNCTIONS = {}
 MEMOIZED_FUNCTIONS = {}
+FUNCTION_ALIASES = {}
 
-
+def aliases(*args):
+    def decorator(f):
+        FUNCTION_ALIASES[id(f)] = args
+        return f
+    return decorator
+    
 def expose(func=None, interval=0, name=None, memoize=False):
     if func is not None:
         EXPOSED_FUNCTIONS[id(func)] = {"interval":interval, "name":name}
@@ -41,12 +47,24 @@ class AWSpiderPlugin(object):
                     instance_method[1],
                     interval=EXPOSED_FUNCTIONS[instance_id]["interval"],
                     name=EXPOSED_FUNCTIONS[instance_id]["name"])
+                if instance_id in FUNCTION_ALIASES:
+                    for name in FUNCTION_ALIASES[instance_id]:
+                        self.spider.expose(
+                            instance_method[1],
+                            interval=EXPOSED_FUNCTIONS[instance_id]["interval"],
+                            name=name)                        
             if instance_id in CALLABLE_FUNCTIONS:
                 self.spider.expose(
                     instance_method[1],
                     interval=CALLABLE_FUNCTIONS[instance_id]["interval"],
                     name=CALLABLE_FUNCTIONS[instance_id]["name"])
-
+                if instance_id in FUNCTION_ALIASES:
+                    for name in CALLABLE_FUNCTIONS[instance_id]:
+                        self.spider.expose(
+                            instance_method[1],
+                            interval=CALLABLE_FUNCTIONS[instance_id]["interval"],
+                            name=name)
+                            
     def setReservationFastCache(self, uuid, data):
         return self.spider.setReservationFastCache(uuid, data)
    
